@@ -42,6 +42,12 @@ impl Parser {
         }
     }
 
+    pub fn with_collect() -> Parser {
+        Parser {
+            args: collect()
+        }
+    }
+
     pub fn contains(&self, ufixed: &str) -> bool {
         self.args.contains(&fix(ufixed))
     }
